"""Settings to access not public era5 data."""

from typing import Tuple


def era5_settings(sampling="daily", era5_data_path=None, era5_file_names=None) -> Tuple[str, str]:
    """
    Check for sampling as only hourly resolution is supported by era5 and return path on HPC systems.

    :param sampling: temporal resolution to load data for, only hourly supported (default "daily")

    :return: HPC path
    """
    if sampling == "hourly":  # pragma: no branch
        ERA5_DATA_PATH = era5_data_path or "."
        FILE_NAMES = era5_file_names or "*.nc"
    else:
        raise NameError(f"Given sampling {sampling} is not supported, only hourly sampling can be used.")
    return ERA5_DATA_PATH, FILE_NAMES
